# contact_sites
package to help analayze organelle to organelle contact sites

installation:
1. create ot activate conda env
2. pip install contact_sites

installation for development:
1. create ot activate conda env
2. for development cd to project dirctory
3. pip install -e .

